@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::date::str_alami;
 
-our $DATE = '2016-06-14'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $DATE = '2017-01-09'; # DATE
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
@@ -61,13 +61,13 @@ Data::Sah::Coerce::perl::date::str_alami - Coerce date from string parsed by Dat
 
 =head1 VERSION
 
-This document describes version 0.006 of Data::Sah::Coerce::perl::date::str_alami (from Perl distribution Data-Sah-Coerce-perl-date-str_alami), released on 2016-06-14.
+This document describes version 0.007 of Data::Sah::Coerce::perl::date::str_alami (from Perl distribution Data-Sah-Coerce-perl-date-str_alami), released on 2017-01-09.
 
 =head1 DESCRIPTION
 
 The rule is not enabled by default. You can enable it in a schema using e.g.:
 
- ["array*", of=>"date", "x.perl.coerce_to"=>"DateTime", "x.perl.coerce_rules"=>["str_alami"]]
+ ["date", "x.perl.coerce_rules"=>["str_alami"]]
 
 =for Pod::Coverage ^(meta|coerce)$
 
@@ -93,7 +93,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
